# extremals

The python module extremals consists in a toolset to inspect pandas dataframes looking for
"extremals rows", that is rows "numerically different" from other ones. This may help filtering a dataframe from anomalous numerical data or, on the
contrary, highlight exceptional rows from common ones.

Visit the webpage for more information: https://fabio-tonini.github.io/extremals/
